Retrieve the average sale price for houses in a particular area.
average_area_sold_price(area = NULL, output = NULL, API_key = NULL)
| area | A string representing desired area. Could be a postcode, outcode, or a name. Should unambiguous, otherwise the API will return an error. |
|---|---|
| output | A string representing desired output: "outcode", "town", "county", "country". This should cover a larger area than the 'area' variable. |
| API_key | An API key from Zoopla. |
A list.
http://developer.zoopla.com/docs/read/Average_area_sold_price
# NOT RUN { average_area_sold_price("Edinburgh", "country", "YOUR_API_KEY") average_area_sold_price("EH1 2NG", "outcode", "YOUR_API_KEY") average_area_sold_price("EH1", "county", "YOUR_API_KEY") # }